@@ -87,11 +87,11 @@ class Batch(BaseModel):
         ]
 
     @staticmethod
-    def fake(configuration: Configuration = Configuration()):
+    def fake(configuration: Configuration):
         """ Make fake batch object """
         batch_size = configuration.process.batch_size
-        satellite_image_size_pixels = configuration.input_data.satellite.satellite_image_size_pixels
-        nwp_image_size_pixels = configuration.input_data.nwp.nwp_image_size_pixels
+        satellite_image_size_pixels = 64
+        nwp_image_size_pixels = 64
 
         return Batch(
             batch_size=batch_size,
@@ -99,7 +99,9 @@ class Batch(BaseModel):
                 batch_size=batch_size,
                 seq_length_5=configuration.input_data.satellite.seq_length_5_minutes,
                 satellite_image_size_pixels=satellite_image_size_pixels,
-                number_sat_channels=len(configuration.input_data.satellite.sat_channels),
+                number_satellite_channels=len(
+                    configuration.input_data.satellite.satellite_channels
+                ),
             ),
             nwp=nwp_fake(
                 batch_size=batch_size,
